#
# spec file for package plantuml
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           plantuml
Version:        1.2024.8
Release:        1.1
Summary:        Java UML Tool
License:        GPL-3.0-or-later
Group:          Productivity/Publishing/Other
URL:            https://plantuml.com/
Source0:        https://github.com/plantuml/plantuml/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source10:       http://pdf.plantuml.net/PlantUML_Language_Reference_Guide_en.pdf
Patch0:         build-with-javac-utf8-encoding.patch
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  javapackages-local
Requires:       javapackages-tools
BuildArch:      noarch

%description
PlantUML is a program allowing to draw UML diagrams, using a simple
and human readable text description. It is extremely useful for code
documenting, sketching project architecture during team conversations
and so on.

PlantUML supports the following diagram types
  - sequence diagram
  - use case diagram
  - class diagram
  - activity diagram
  - component diagram
  - state diagram

%package javadoc
Summary:        Javadoc for %{name}
Group:          Productivity/Publishing/Other

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q
%patch -P 0 -p1
cp %{SOURCE10} .

%build
ant

# build javadoc
export CLASSPATH=$(build-classpath ant):plantuml.jar
javadoc \
    -source 1.8 \
    -encoding UTF-8 \
    -notimestamp \
    -Xdoclint:none \
    -d javadoc \
    -windowtitle "PlantUML %{version}" \
    $(find src -name "*.java")

%install
# Set jar location
install -dm 0755 %{buildroot}%{_javadir}
install -pm 0644 %{name}.jar %{buildroot}%{_javadir}/%{name}.jar
# Configure maven depmap
%add_maven_depmap  net.sourceforge.%{name}:%{name}:%{version} %{name}.jar
# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
cp -r javadoc/* %{buildroot}%{_javadocdir}/%{name}/
%fdupes %{buildroot}%{_datadir}
# launcher script
%jpackage_script net.sourceforge.plantuml.Run "" "" %{name} %{name}

%files -f .mfiles
%{_bindir}/%{name}
%license COPYING

%files javadoc
%{_javadocdir}/%{name}
%license COPYING

%changelog
* Mon Nov 18 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.24.8
  * Allow MinimumWidth on all nested elements.
  * fix: improve edge cases for JSON diagram (manage null and
    empty Array/Object).
  * use latex to get string bounder.
  * tikz: make all fonts with the same baseline.
  * tikz: avoid latex manager crash for special characters.
  * tikz: use the same protectText when calc dimension and render.
  * tikz: optimize latex render.
  * optimize tikz render.
  * upd: uniformisation of dirpath.
  * feat: reintroduction of filedate and filenamenoextension
    builtin function.
  * feat: Allow Unicode ASCII Art for class, component.
  * fix: error in namespace management.
  * Style: Improve map and json style in order to manage header
    style.
  * Gantt with monthly scale doesn't show named regions.
  * fixing proprietary licenses in PlantUML software package of
    Replicant project.
  * Allow stereotype for arrow, on sequence diagram.
  * Allow LineStyle for arrow, on sequence diagram.
  * feat: Allow stereotype for Clock on Timing diagram.
  * Allow stereotype on Timing diagram.
  * Style: Allow stereotype on note for all diagram type.
  * State machine invalid generation for SVG.
  * Update C4-PlantUML to v2.11.0.
  * Style: Allow all style for Cardinality, Generic, Qualified
    associations on Class diagram.
  * nwdiag: Allow line border for group.
  * Style: Allow all style for regex diagram.
  * Style: Allow theme and style for files list diagram.
  * feat: allow all JSON Values on JSON.
  * Compact clocks in timing diagrams not rendered correctly.
- Update to version 1.24.7
  * [Class][Deployment] Some issues about arrow between nested
    elements.
  * Crash happened on plantuml 1.2024.7beta5, related to "headless"
  * hide does not work inside package.
  * After v1.2023.10, Remove command does not remove nested shapes.
  * When adding specific note at specific position, activity
    diagram not work.
  * Custom Theme loading.
  * [Creole] Fix color.
  * repeat starting point is in wrong swimlane.
  * Generate a svg:title tag when generating Svg.
  * fix: make native release as snapshot release.
  * feat: add builtin function %%boolval.
  * feat: add builtin function %%mod (modulo operator).
  * Added background color to arrows and draw background for circles.
  * remove duplicate items in help message.
  * [Sprite][SVG] Manage more SVG functionalities for text.
  * pdf support broken with other gradle build file changes.
  * Allow style for backward element on repeat loop, on Activity
    diagram.
  * Allow >> and > on the same arrow.
  * Pause a task up to end of another task.
  * Rendering issue when nesting different elements.
  * Allow multiple style stereotypes for Mindmap, WBS.
  * Gantt: Weekscale with weeknumbers.
  * The utilization of resources does not color red correctly when
    week partly closed.
  * Remove and restore not working as expected.
- Update to version 1.24.6
  * Improve Eclipse Layout Kernel support.
  * groups (e.g. alt) with else cannot be rendered in parallel.
  * alt/else block shown in parallel using teoz leads to wrong
    formatting.
  * Teoz: Shape of note changes only when "over" is used.
  * multiple activation of lifelines does not render properly in
    sequence diagrams.
  * 2024.5 breaks https includeurl.
  * Incorrect object reference in Gantt Chart.
  * Activity: Allow to style SDL on Repeat While loop.
  * inconsistent computation of group/alt/opt box size given left
    or right arrows.
  * !foreach $key from %%get_json_keys() is not found by
    %%json_key_exists(), but works for element access.
  * Allow scale max on JSON and YAML diagram.
  * [ELK][Smetana] Allow Fontcolor style on arrows.
  * [Style][WBS] Change (arrow) line color of a specific branch.
  * Elk: Allow full style on arrows (except fontcolor).
  * feat: math: add newline command for formatting.
  * feat: add support for [one-line] title to JSON diagram.
  * Performance issue with JRE21.
  * Fix parallel group active levels.
  * Extend @@@format to support more formats.
  * [teoz] [bug] [sequence] Group becomes too wide when containing
    activations.
  * [Theme] sunlust theme does not work for JSON or YAML
    diagram/data.
- Update to version 1.24.5
  * BUG: Activation is offset (Sequence diagram, Teoz).
  * teoz: activation breaks parallell lines.
  * sequence lifeline height badly depends on message height.
  * Sequence diagram: Wrong start/end of activation boxes in
    activation boxes while using teoz.
  * The display of text, line, and arrow on the left side of the
    Lifeline is incorrect.
  * the location of the Comment is INCORRECT.
  * teoz arrow alignment.
  * activate/deactivate issues.
  * Inline multicast activate only activates the first target.
  * Activation is offset (Using Teoz).
  * Small rendering difference between default and Teoz.
  * Side effect of variable management when using %%json_add.
  * timing diagram initial concise state.
  * Java OutOfMemoryError with some Sequence diagrams.
  * Smetana is not supporting colors in UML.
  * Timing: Set background color of concise.
  * (timing diagram) message labels ignore default style.
  * "off by one errors" in text output.
  * hyperlinkUnderline causes NumberFormatException.
  * Wrong component is highlighted on hover for
    svginteractive.
  * [Theme] sunlust theme does not work for JSON or YAML
    diagram/data.
  * Stereotype won't be hidden with "hide stereotype".
  * [Chen ERD] Allow horizontal layout or left to right direction.
  * add %%splitstrregex builtin function.
  * ASCIIMathTeXImg.java with a lot of corrections/enhancements.
  * add new JSON builtin functions (%%str2json, %%json_add and
    %%json_remove).
  * add new JSON builtin function (%%json_set).
  * add new JSON builtin function (%%json_merge).
  * Fix on osa2 and Classy.
* Thu Oct  3 2024 Fridrich Strba <fstrba@suse.com>
- Clean the spec file a bit and generate the launcher script from
  the spec file using the %%%%jpackage_script macro
  + Fixes running with javapackage-tools >= 6.3
* Sun Sep 29 2024 Fridrich Strba <fstrba@suse.com>
- Fix build after removal of the default %%%%{java_home} define
* Sun Apr  7 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.24.4
  * Implement Chen Notation for ER-diagrams.
  * Add a tool-independent XMI format.
  * feat: add %%get_all_stdlib builtin function.
  * fix: suppress @[start|end]uml on sunlust theme.
  * How to extends a generic class.
  * Negative values causing syntax error in robust "has" list.
  * Activity Diagram: Style of multiline Box.
  * Allow style for multi-line elements on Activity diagram.
  * EIP standard library.
- Update to version 1.24.2
  * Update standard library.
  * feat: add %%get_all_theme builtin function.
  * fix: update graphviz version check pattern.
  * Add theme Sunlust.
  * feat: Improve new Random function.
  * Improve Chronology diagram management.
  * add: Language Descriptor Improvement (adding action and
    process).
* Wed Feb 21 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Sat Feb  3 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.24.0
  * Gantt Layout issue when Print between is used with Printscale
    weekly.
  * Teoz produces odd legend for sequence diagrams.
  * Note invalid position in Directory tree listing
  * Shape "activity" ist hardly missing.
  * Allow full local style (for while, repeat) on Activity diagram.
  * Allow full local style (for if diamonds) on Activity diagram.
  * Color individual conditional in activity diagram.
  * Bug with activity diagram arrows fork.
* Thu Dec 14 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2023.13
  * Javadoc improvement.
  * Bug with activity diagram arrows fork.
  * Is is possible to change the milestone icon from a diamond?.
  * Gantt crashes with specific Project start dates.
  * Add support to style timeline fonts for gantt charts.
  * Directory tree listing.
  * Unable to set MaximumWidth style for legend.
  * Wrong note shape in sequence diagram when arrow has only one
    participant.
  * GANTT: How to handle if a resource starts or terminates at a
    specific date.
  * Is it possible to set gantt tasks to be incomplete by default.
  * [Style] Allow LineThickness style for awesome Actor on
    Component/UC/Deployment diagram
  * [Style] Allow multiple style stereotypes for backward element
    on Activity diagram
  * Syntax error on two and more array items in macros
- Update to version 1.2023.12
  * Crash on sample DITAA diagram.
  * Only one transition permitted to State[H] in state diagram.
  * Rendering issue when nesting different elements (partially).
  * force notes to use inner namespaces not global namespace only.
  * ASL distribution no longer includes graphiz.dat.
  * ASL distribution no longer includes OpenIconic SVGs.
- Update to version 1.2023.11
  * [Style] Allow style for backward element on Activity diagram.
  * Sequence diagram: Multi-level nested boxes overlaying each
    other.
  * Using -cypher does not always recognize restricted words.
  * Verticals separators in gantt chart don't appear under certain
    conditions.
  * namespace/package consolidation broke existing remove/restore
    behaviour when using namespace separators.
  * Last label on last elseif branch does not get rendered.
  * no colored border on state start/end.
  * Qualifier labels and associations' lines not correctly drawn
    for qualified associations.
  * Notes on conditionnal elements.
  * Update C4-PlantUML to v2.8.0.
  * Handle @start/@end syntax error better.
- Update to version 1.2023.10
  * Exception error when adding note to timing diagram.
  * Skinparam inconsistencies on class diagram grouping elements.
  * Batik SVG rendering: The attribute "width" of the element
    'rect' is required.
  * skinParam fixCircleLabelOverlapping doesn't work anymore.
  * Using an external style file by pointing to a URL or by using
    a relative file path doesn't work.
  * Add regex, files on Embedded Diagram.
- Update to version 1.2023.9
  * nwdiag possible misbehavior.
  * Replace old ALLOW_PLANTUML_INCLUDE flag by security profile.
    sprite transparent issue.
  * Alpha feature: Directory tree listing.
  * Smetana and ELK: Improve nested elements with last {}
    declaration.
  * [Font][Skinparam or Style] Issues on fall back font (partly).
  * Decimal time values not accepted in parameters or procedures.
- Update to version 1.2023.8
  * First support for regular expression.
  * !theme supports no calculated from path and no stdlib from
    path.
  * Grammar error occurs when specifying full-width digits with
    the "as" keyword in timing diagrams.
* Mon Sep 18 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2023.7
  * Activity: Allow to style SDL stereotype.
  * Activity: Allow post-positioned stereotype style.
  * specifying full-width digits with the "as" keyword in timing
    diagrams.
  * force notes to use inner namespaces not global namespace only.
  * teoz: Support notes on references.
  * Activity diagram, Case statement, arrow label missing.
  * When connecting attributes between object graphs, the
    connection error.
- Update to version 1.2023.6
  * Gantt Milestone with Multiline Text Placement.
  * Start and end nodes can only be styled globally in CSS style.
  * Gantt diagram - Can't close day in the period of opened days.
  * Support notes on references.
  * [gantt] make it possible to color last day.
  * Automatic font color with gradient participant background
    creates UnsupportedOperationException.
  * ConditionStyle InsideDiamond not working for elseif.
  * StateBackgroundColor transparent is not effective.
  * Multible breaks in one repeat.
- Update to version 1.2023.5
  * Error in generating State Diagram.
  * Bug - Crowfoot notation on ERD rendering buggy.
  * Regarding the February update with intermediate
    namespaces.
  * Malformed layout and missing arrows on large amount of
    edges.
  * Smetana and ELK: Improve arrow position and suppress empty
    space.
  * [Class] Note on field is considered unlinked.
  * 'help preprocessors' command is not working.
  * JSON diagram SVG has misplaced arrows when containing
    newlines.
  * [Smetana] Allow notes (or comments) on lines or links.
  * ClassAttributeFont(Style|Size|...) overrides
    ClassFontStyle(Style|Size|...).
  * The command help themes to list all the themes of PlantUML
    seems broken.
  * Note and position not rendering correctly on CheerpJ.
  * Notes linked to messages in Sequence Diagrams.
  * !global $variable ?= "default variable" produces error "a001".
  * Allow only one underscore when escaping.
  * Using end if as an alias for endif in Activity diagrams.
  * Drastic Behavior Change of "as" Parsing with "." (period).
  * nwdiag bug: group causes element to incorrectly connect to
    network
- Update to version 1.2023.4
  * Improve backward compatibility about package and namespace
    simplification.
  * Allow only one underscore when escaping.
  * Using end if as an alias for endif in Activity diagrams.
  * Ability to hide empty fields for object diagrams.
  * Namespace association class connection point outside namespace.
  * Dotted arrow --> is also the close of comment blocks
* Mon Feb 27 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2023.2
  * package and namespace simplification
  * .repx file generation
  * Cannot set long name arrow label in repeat statement with break
  * together behaves different starting from 1.2023.0
  * Possible regression with class alias declaration
  * The footer is not displayed at the footer
  * latex and package: no perpendicular corners
  * Allow full style on label of Port, Point, Pin
  * Structs do not function properly within a namespace
  * Nwdiag problem with address label position on peer network
  * Update tupadr3 in the stdlib
* Sun Jan 29 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2023.1
  See http://plantuml.com/de/changes for all changes
* Thu Jan 12 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2023.0
  See http://plantuml.com/de/changes for all changes
* Fri Dec 16 2022 Michael Ströder <michael@stroeder.com>
- Update to version 1.2022.14
  See http://plantuml.com/de/changes for all changes
* Sun Sep 18 2022 Markus Ebner <info@ebner-markus.de>
- Update to version 1.2022.7
  See http://plantuml.com/de/changes for all changes
* Mon May 16 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2022.5
  See http://plantuml.com/de/changes for all changes
  * Fix CVE-2022-1379 (bsc#1199557)
- Update patch
  * build-with-javac-utf8-encoding.patch
* Tue Apr 19 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2022.4
  See http://plantuml.com/de/changes for all changes
  * Fix CVE-2022-1231 (bsc#1198591)
* Wed Mar 30 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2022.3
  See http://plantuml.com/de/changes for all changes
* Wed Jan 12 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2022.0
  See http://plantuml.com/de/changes for all changes
* Mon Nov  1 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2021.13
  See http://plantuml.com/de/changes for all changes
* Sun Oct 17 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2021.12
  See http://plantuml.com/de/changes for all changes
* Thu Sep 16 2021 Markus Ebner <info@ebner-markus.de>
- Update to version 1.2021.10
  See http://plantuml.com/de/changes for all changes
- Add patch:
  * build-with-javac-utf8-encoding.patch
* Sun Apr  4 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2021.4
  See http://plantuml.com/de/changes for all changes
* Tue Mar 23 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2021.3
  See http://plantuml.com/de/changes for all changes
- Drop patch:
  * remove-non-ascii-char.patch (fixed upstream)
* Fri Mar  5 2021 Markus Ebner <info@ebner-markus.de>
- Cleanup
- Update to version 1.2021.1
  See http://plantuml.com/de/changes for all changes
- Build plantuml-javadoc package
- Add patch:
  * remove-non-ascii-char.patch
* Tue Oct 20 2020 Pedro Monreal <pmonreal@suse.com>
- Update link to the pdf manual in the plantuml.xml file
* Mon Oct 12 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2020.19
  See http://plantuml.com/de/changes for all changes
* Thu Oct  1 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2020.18
  See http://plantuml.com/de/changes for all changes
* Sun Sep 20 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2020.17
  See http://plantuml.com/de/changes for all changes
* Mon Aug 24 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2020.15
  See http://plantuml.com/de/changes for all changes
* Wed Jun 17 2020 Fridrich Strba <fstrba@suse.com>
- Documentation fix: [bsc#1169765]
  * Fetch the PlantUML_Language_Reference_Guide_en.pdf instead of
    a web page that wraps the PDF in javascript feeding ads.
* Wed Jun 17 2020 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- update to version 1.2020.13
  See http://plantuml.com/de/changes for all changes
* Wed Jun 10 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2020.12
  See http://plantuml.com/de/changes for all changes
* Sun May 10 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2020.9
  See http://plantuml.com/de/changes for all changes
* Tue Apr 28 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2020.8
  See http://plantuml.com/de/changes for all changes
* Mon Apr  6 2020 Andreas Hasenkopf <ahasenkopf@suse.com>
- Added requirement 'dejavu-fonts'
* Sun Apr  5 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2020.6
  See http://plantuml.com/de/changes for all changes
* Wed Dec 11 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2019.13
  See http://plantuml.com/de/changes for all changes
* Wed Nov  6 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2019.12
  See http://plantuml.com/de/changes for all changes
* Sun Sep 22 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2019.11
  See http://plantuml.com/de/changes for all changes
* Mon Sep 16 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2019.10
  See http://plantuml.com/de/changes for all changes
* Tue Aug 27 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2019.9
  See http://plantuml.com/de/changes for all changes
* Mon May 27 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2019.6
  See http://plantuml.com/de/changes for all changes
* Mon Apr 29 2019 Martin Hauke <mardnh@gmx.de>
- Update to new upstream version 1.2019.4
- Restore original changelog entries
* Fri Feb  8 2019 ahasenkopf@suse.com
- Fixed package internal issues
* Fri Jan 11 2019 ahasenkopf@suse.com
- First commit for version 1.2018.14
* Tue Sep  4 2018 mardnh@gmx.de
- Update to new upstream version 1.2018.10
- Run spec-cleander
* Tue Aug 25 2015 michiel.vanderwulp@gmail.com
- Improve the man page
* Thu Aug 20 2015 michiel.vanderwulp@gmail.com
- Update to PlantUML 8029
* Fri Jun  5 2015 michiel.vanderwulp@gmail.com
- Update to PlantUML 8025
* Sun Sep  4 2011 toms@suse.de
- Initial version 7177
